@@ -90,7 +90,8 @@ class NetBoxInventory:
         ssl_verify: Union[bool, str] = True,
         flatten_custom_fields: bool = False,
         filter_parameters: Optional[Dict[str, Any]] = None,
-        include_vms: bool = False,
+        #include_vms: bool = False,
+        include_vms: bool = True,
         use_platform_slug: bool = False,
         use_platform_napalm_driver: bool = False,
         **kwargs: Any,
@@ -138,11 +139,20 @@ class NetBoxInventory:
             params=self.filter_parameters,
         )
 
+        #params = self.filter_parameters["tag"]
+        #nb_devices.extend(
+        #    self._get_resources(
+        #        url=f"{self.nb_url}/api/dcim/devices/?limit=0",
+        #        params=params,
+        #    )
+        #)
+        
         if self.include_vms:
+            params = self.filter_parameters["tag"]
             nb_devices.extend(
                 self._get_resources(
                     url=f"{self.nb_url}/api/virtualization/virtual-machines/?limit=0",
-                    params=self.filter_parameters,
+                    params=params,
                 )
             )
 
@@ -275,5 +285,7 @@ class NetBoxInventory:
                 # Case where circuit status is decomissioned and does not have peers anymore
                 continue
             
-        devices = devices_dict.values()
+        devices = []
+        for key in devices_dict.keys():
+            devices.append(devices_dict[key])
         return devices
