@@ -19,7 +19,7 @@ NB_TOKEN = os.environ.get("NB_TOKEN")
 
 class NetboxManager:
     """
-    NetboxManager manages the object that hosts infrastruxture data from NetBox host.
+    NetboxManager manages the object that hosts infrastruc ture data from NetBox host.
     
     TODO: write docstrings
     ...
@@ -81,35 +81,55 @@ class NetboxManager:
         host.port = ""
         host.username = ""
         host.password = ""
-        host.platform = "junos"
-        # This function receives a Host object for manipulation
-        port = self._nb.secrets.secrets.get(
-            device_id=host["id"], 
-            name="port"
-        )
-        username = self._nb.secrets.secrets.get(
-            device_id=host["id"], 
-            name="username"
-        )
-        password = self._nb.secrets.secrets.get(
-            device_id=host["id"], 
-            name="password"
-        )
+        if 'virtual-machines' in host['url']:
+            port = self._nb.secrets.secrets.get(
+                virtual_machine_id=host["id"], 
+                name="port"
+            )
+            username = self._nb.secrets.secrets.get(
+                virtual_machine_id=host["id"], 
+                name="username"
+            )
+            password = self._nb.secrets.secrets.get(
+                virtual_machine_id=host["id"], 
+                name="password"
+            )
+        else:
+            port = self._nb.secrets.secrets.get(
+                device_id=host["id"], 
+                name="port"
+            )
+            username = self._nb.secrets.secrets.get(
+                device_id=host["id"], 
+                name="username"
+            )
+            password = self._nb.secrets.secrets.get(
+                device_id=host["id"], 
+                name="password"
+            )
+
+        if host["platform"] == "null":
+            platform = "junos"
+        else:
+            platform = host['platform']['slug']
+
         if port and username and password:
             host.port = port.plaintext
             host.username = username.plaintext
             host.password = password.plaintext
+            host.platform = platform
         else:
             print("No secrets found on device ", host["name"])
             exit(1)
             
-        host.connection_options["netmiko"] = {"extras": {"timeout": 60}}
+        #host.connection_options["netmiko"] = {"extras": {"timeout": 60}}
         # print("Paramiko timeout:", host.connection_options["paramiko"]["extras"]["timeout"])
 
         print("----------------")
         print("# DEVICE INVENTORY ITEM")
         print("Device:", host.name)
         print("Hostname:", host.hostname)
+        print("Platform:", host.platform)
         # print("Connection options:", dict(host.connection_options))
         print("----------------")
 
@@ -125,7 +145,7 @@ class NetboxManager:
         # MUDANCA filter_parameters
         options = {
             "nb_url": self.nb_url,
-            "nb_token": self.nb_token,   
+            "nb_token": self.nb_token,
         }
         if self.filter_parameters:
             options["filter_parameters"] = self.filter_parameters
