@@ -98,6 +98,19 @@ def get_circuit_terminations(params: Dict[str, Any] = None):
     return terminations
 
 
+def get_device_by_name(device_name):
+    """
+	TODO: write docstrings
+	"""
+
+    devices = nb_api.dcim.devices.filter(
+        name=device_name)
+    device = {}
+    for d in devices:
+        device = d
+    return device
+
+
 def get_resources(url: str, params: Dict[str, Any]) -> List[Dict[str, Any]]:
     """
 	TODO: write docstrings
