@@ -1,7 +1,15 @@
 import re
+from click import command
+import paramiko
+import json
 
 from lxml import etree
 from jnpr.junos.exception import ConnectError
+from nornir_napalm.plugins.tasks import napalm_get
+from nornir_utils.plugins.functions import print_result
+from nornir_scrapli.tasks import send_command
+from nornir_paramiko.plugins.connections import Paramiko
+from nornir_paramiko.plugins.tasks import paramiko_command
 
 from ..utils.utils import (
     print_json,
@@ -216,7 +224,7 @@ def junos_pyez_check_configs(xml_data, format):
 
 def junos_pyez_get_interfaces(config_dict):
     """
-    Get configured interfaces from configuration dictionary <config_dict>, except of lo0.
+    Get configured interfaces from configuration dictionary <config_dict>, except of unavailable_interfaces.
 
     Input:
             config_dict: junos pyez configuration dictionary (json-like)
@@ -256,3 +264,138 @@ def junos_pyez_convert_configs_2_list(config_str, comp_strings):
         if valid_config:
             configs_list.append(line)
     return configs_list
+
+
+def linux_paramiko_get_configs(nornir=None, dev_name=None, format='json'):
+    """
+    Get Junos device configs using Juniper PYEZ library.
+
+    Input:
+            nornir: nornir object
+            dev_name: device name equal to the name available in nornir inventory
+            format: linux config output format (json, commands)
+    Output:
+            Logical Object (LO) config statements
+    """
+    # Get inventory data from Nornir
+    nornir_host_data = nornir.inventory.hosts[dev_name].dict()
+    host = nornir_host_data["hostname"]
+    port = nornir_host_data["port"]
+    username = nornir_host_data["username"]
+    password = nornir_host_data["password"]
+    
+    #unavailable_interfaces = ['docker', 'lo', 'br', 'tunnel']
+    # Set SSH Client connection
+    ssh = paramiko.SSHClient()
+    ssh.set_missing_host_key_policy(paramiko.AutoAddPolicy())
+        
+    # Try to connect to host 3 times
+    retry = True
+    retry_num = 0
+    max_retries = 3
+    while retry:
+        try:
+            ssh.connect(host, port, username, password)
+            retry = False
+        except Exception as e:
+            print(e)
+            retry_num+=1
+            if retry_num > max_retries:
+                retry = False
+    
+    # Set linux configuration object
+    configs = {
+        'interface': {},
+        'route': [],
+    }
+    # Set list of configuration statements for linux host
+    config_commands = []
+    
+    # Get interface data from IP utility in linux
+    show_int_command = "ip addr show"
+    stdin, stdout, stderr = ssh.exec_command(show_int_command)
+    lines = stdout.readlines()
+    
+    for line in lines:
+        if 'UP' in line or 'DOWN' in line:
+            interface = line.split(":")[1].replace(" ", "")
+            configs['interface'][interface] = {'name': interface}
+            configs['interface'][interface]['ipv4_addr'] = None
+            configs['interface'][interface]['ipv6_addr'] = None
+            if 'LOOPBACK' in line:
+                admin_state = line.split('>')[0].split(',')[1]
+            elif 'NO-CARRIER' not in line:
+                admin_state = line.split('>')[0].split(',')[2]
+            else:
+                admin_state = line.split('>')[0].split(',')[3]
+            configs['interface'][interface]['admin_state'] = admin_state
+            configs['interface'][interface]['oper_state'] = line.split('state ')[1].split(' ')[0]
+
+        if 'inet' in line and 'inet6' not in line:
+            addr_list = line.split(" ")
+            for str in addr_list:
+                if "/" in str:
+                    ipv4_addr = str
+            configs['interface'][interface]['ipv4_addr'] = ipv4_addr
+    
+    for int in configs['interface']:
+        if configs['interface'][int]['ipv4_addr']:
+            config_commands.append(f"ifup {int}")
+            config_commands.append(f"ip addr add {configs['interface'][int]['ipv4_addr']} dev {int}")
+
+    # Get IP route commands
+    show_route_command = "ip route show"
+    stdin, stdout, stderr = ssh.exec_command(show_route_command)
+    lines = stdout.readlines()
+
+    for line in lines:
+        config_route = line.split(' \n')[0]
+        configs['route'].append(config_route)
+        config_commands.append(f"ip route add {config_route}")
+        #TODO add other routes
+
+    # Close SSH connection
+    ssh.close()
+
+    if format == 'json':
+        return configs
+    elif format == 'commands':
+        return '\n'.join(config_commands)
+        
+
+
+def linux_paramiko_get_interfaces(nornir_host=None):
+    """
+    Get Junos device configs using Juniper PYEZ library.
+
+    Input:
+            nornir: nornir object
+            dev_name: device name equal to the name available in nornir inventory
+    Output:
+            Logical Object (LO) config statements
+    """
+    
+    host = "200.159.254.86"
+    port = 22
+    username = "staff-pop"
+    password = "rnppoprjabc123!!"
+
+    show_command = "ip addr show"
+
+    ssh = paramiko.SSHClient()
+    ssh.set_missing_host_key_policy(paramiko.AutoAddPolicy())
+    ssh.connect(host, port, username, password)
+
+    stdin, stdout, stderr = ssh.exec_command(show_command)
+    lines = stdout.readlines()
+    interfaces_list = []
+    for line in lines:
+        if 'UP' in line or 'DOWN' in line:
+            interfaces_list.append(line.split(":")[1].replace(" ", ""))
+            
+    return interfaces_list
+
+
+
+    ############################
+    # FINALIZAR GET INTERFACES E GET CONFIGS LINUX E CONSTRUIR DB
