@@ -68,4 +68,37 @@ def pyez_device(nornir, device_name):
         port=nornir.inventory.hosts[device_name].port
     )
     
-    return dev
\ No newline at end of file
+    return dev
+
+
+def linux_config_dev():
+    """ 
+    TODO: write docstrings
+    Retorna o Objeto de descricao de dados de configuracoes para dispositivo linux, onde:
+        * 'interface': dados de interface do tipo Dict (linux_config_interface)
+        * 'route': dados de rotas do tipo lista (cada item e uma descricao de rota)
+    """
+    obj = {
+        'interface': {},
+        'route': [],
+    }
+
+    return obj
+
+
+def linux_interface_config_data():
+    """ 
+    TODO: write docstrings
+    Retorna o Objeto de descricao de dados de configuracoes para dispositivo linux, onde:
+        * 'interface': dados de interface do tipo Dict (linux_config_interface)
+        * 'route': dados de rotas do tipo lista (cada item e uma descricao de rota)
+    """
+    obj = {
+        'name': None,
+        'ipv4_addr': None,
+        'ipv6_addr': None,
+        'admin_state': None,
+        'oper_state': None
+    }
+
+    return obj
\ No newline at end of file
