@@ -1,5 +1,6 @@
 from slugify import slugify
 from nornir.core.exceptions import ConnectionNotOpen, NornirExecutionError
+from nornir_napalm.plugins.tasks import napalm_get
 
 from netops.utils.utils import print_json
 from .models import (PORT_MAPPING_DB, PORTS_TABLE, INVALID_JUNOS_CONFIG_STATEMENTS, PORTS_COLUMN_NAMES)
@@ -13,7 +14,9 @@ from ..utils.databases import (
 from ..configs.get_configs import (
     junos_pyez_get_configs,
     junos_pyez_convert_configs_2_list,
-    junos_pyez_get_interfaces
+    junos_pyez_get_interfaces,
+    linux_paramiko_get_interfaces,
+    linux_paramiko_get_configs
 )
 from ..configs.models import pyez_device
 
@@ -35,16 +38,22 @@ def gen_junos_interfaces_list(int_number):
     return interface_list
 
 
-def get_interface(int_list):
+def get_interface(int_list, int_name=None):
     """
-    Get interface from list of interface names.
+    Get interface from list of interface names based in given interface name if it has been input and
+    remove the interface from the list or pop the first item from the interface list.
 
     Input:
             int_list: list of interfaces
+            int_name: name of the interface to be get from interface list
     Output:
             name of interface
     """
-    return int_list.pop(0)
+    if int_name:
+        int_list.remove(int_name)
+        return int_name
+    else:
+        return int_list.pop(0)
 
 
 def create_port_map_db(dev_name):
@@ -109,7 +118,7 @@ def map_po_2_lo_configs(configs_list, port_map):
     return configs_list
 
 
-def get_junos_lo_configs(nornir=None, dev_name=None, dev=None, con_ints=None):
+def get_junos_lo_configs(nornir=None, dev_name=None, dev=None, connected_interfaces=None):
     """
     Get Junos device configs using Juniper PYEZ library.
 
@@ -117,7 +126,7 @@ def get_junos_lo_configs(nornir=None, dev_name=None, dev=None, con_ints=None):
             nornir: nornir object
             dev_name: device name equal to the name available in nornir inventory
             dev: junos pyez device (used just if nornir and dev_name are not specified)
-            con_ints: (connected interfaces) list of interface names of connected interfaces and its link id
+            connected_interfaces: (connected interfaces) list of interface names of connected interfaces and its link id
                         {id: <int>, iface: <str>}
     Output:
             Logical Object (LO) config statements
@@ -137,9 +146,11 @@ def get_junos_lo_configs(nornir=None, dev_name=None, dev=None, con_ints=None):
     # Statements mapping
     po_clist = junos_pyez_convert_configs_2_list(device_configs_set, INVALID_JUNOS_CONFIG_STATEMENTS)
 
-    # Get PO interface names
+    # Get Physical Object interface names
     po_int = junos_pyez_get_interfaces(device_configs)
-    # Get LO available interface names
+    print("Junos po_int list: ", po_int)
+
+    # Get Logical Object available interface names
     avail_lo_int = gen_junos_interfaces_list(256)
 
     # Create PORT MAPPING database
@@ -149,19 +160,19 @@ def get_junos_lo_configs(nornir=None, dev_name=None, dev=None, con_ints=None):
 
     # Populate PORT MAPPING database with lo-interface and po-interface pairs
     data = []
-    last_i = 0
-    if con_ints:
-        for i in range(len(con_ints)):
-            data.append( (i, con_ints[i]['iface'], get_interface(avail_lo_int)) )
-            last_i = i
-    for i in range(last_i+1, len(po_int)):
+    len_po_int = len(po_int)
+    i = 0
+    if connected_interfaces:
+        for i in range(len(connected_interfaces)):
+            data.append( (i, get_interface(po_int, int_name=connected_interfaces[i]['iface']), get_interface(avail_lo_int)) )
+    for i in range(i+1, len_po_int):
         data.append( (i, get_interface(po_int), get_interface(avail_lo_int)) )
     
     put_data_db(pm_db_name, PORTS_TABLE, PORTS_COLUMN_NAMES, data)
 
     # Get all values in PORT MAPPING DATABASE
     tb_values = get_values_from_table(pm_db_name, PORTS_TABLE)
-    print("Port mapping DB: ", tb_values)
+    #print("Port mapping DB: ", tb_values)
     
     # Convert Physical Objects configs to Logical Objects configs based on PORT MAPPING database
     lo_clist = map_po_2_lo_configs(po_clist, tb_values)
@@ -169,4 +180,30 @@ def get_junos_lo_configs(nornir=None, dev_name=None, dev=None, con_ints=None):
     # Delete PORT MAPPING database
     delete_db(pm_db_name)
 
-    return '\n'.join(lo_clist)
\ No newline at end of file
+    return '\n'.join(lo_clist)
+
+
+def get_linux_lo_configs(nornir=None, dev_name=None):
+    """
+    Get Junos device configs using Juniper PYEZ library.
+
+    Input:
+            nornir: nornir object
+            dev_name: device name equal to the name available in nornir inventory
+    Output:
+            Logical Object (LO) config statements
+    """
+    # Get Physical Object (PO) config statements
+    device_configs = linux_paramiko_get_configs(nornir=nornir, dev_name=dev_name, format='json')
+    print("Device configs json: ")
+    print_json(device_configs)
+    device_configs_commands = linux_paramiko_get_configs(nornir=nornir, dev_name=dev_name, format='commands')
+    print("Device configs commands: ")
+    print(device_configs_commands)
+
+    # Get Physical Object interface names
+    #po_int = linux_paramiko_get_interfaces(device_configs)
+    #print("Linux po_ints: ", po_int)
+
+    #return device_configs
+    
\ No newline at end of file
